# adam_core/utils/helpers/data

This directory contains several CSVs with data that can be used for testing.

The csv files are generated by running `python get_test_data.py` from this directory.

### objects.csv

Contains a list of object IDs that can be understood by JPL services (Horizons, SBDB, etc). This list
is used to generate the following two CSVs.

### orbits.csv

Each object ID from the list above is queried from JPL SBDB and stored as an `~adam_core.orbits.orbits.Orbits` object.

### elements_{origin}_{frame}.csv

The orbital elements in Cartesian, Keplerian, and Cometary representations from JPL Horizons for each object are stored
in this file. For barycentric orbits, the origin is "ssb". For heliocentric orbits, the origin is "sun". The frame is
"ec" for ecliptic, "eq" for equatorial.

### propagated_orbits.csv

Contains propagated state vectors (queried from Horizons) for each object at one day intervals for 30 days before and after
the epoch at which the orbits were queried. The propagated orbits are stored as `~adam_core.orbits.orbits.Orbits` objects.

### ephemeris.csv

Contains the predicted ephemeris for each object at the same times as the propagated orbits but as viewed from the Rubin
Observatory (X05).
